package com.cmvr.aima.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.cmvr.aima.domain.AimaTestLog;

/**
 * 爱玛测试日志Mapper接口
 * 
 * @author cmvr-iot
 * @since 2026-06-22
 */
public interface AimaTestLogMapper extends BaseMapper<AimaTestLog> {
    /**
     * 查询爱玛测试日志
     * 
     * @param id 爱玛测试日志主键
     * @return 爱玛测试日志
     */
    AimaTestLog selectAimaTestLogById(String id);

    /**
     * 查询爱玛测试日志列表
     * 
     * @param aimaTestLog 爱玛测试日志
     * @return 爱玛测试日志集合
     */
    List<AimaTestLog> selectAimaTestLogList(AimaTestLog aimaTestLog);

    /**
     * 新增爱玛测试日志
     * 
     * @param aimaTestLog 爱玛测试日志
     * @return 结果
     */
    int insertAimaTestLog(AimaTestLog aimaTestLog);

    /**
     * 修改爱玛测试日志
     * 
     * @param aimaTestLog 爱玛测试日志
     * @return 结果
     */
    int updateAimaTestLog(AimaTestLog aimaTestLog);

    /**
     * 删除爱玛测试日志
     * 
     * @param id 爱玛测试日志主键
     * @return 结果
     */
    int deleteAimaTestLogById(String id);

    /**
     * 批量删除爱玛测试日志
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteAimaTestLogByIds(String[] ids);
}
